pub trait ModulusSize: ArraySize + Add<UInt<UTerm, B1>, Output = Self::CompressedPointSize> {
type CompressedPointSize: ArraySize + Add<Self, Output = Self::UncompressedPointSize>;
type UncompressedPointSize: ArraySize;
type UntaggedPointSize: ArraySize + Sub<Self, Output = Self>;
}Expand description
Trait for supported modulus sizes which precomputes the typenums for various point encodings so they don’t need to be included as bounds.
Required Associated Types
Sourcetype CompressedPointSize: ArraySize + Add<Self, Output = Self::UncompressedPointSize>
type CompressedPointSize: ArraySize + Add<Self, Output = Self::UncompressedPointSize>
Size of a compressed point for the given elliptic curve when encoded using the SEC1
Elliptic-Curve-Point-to-Octet-String algorithm (including leading 0x02 or 0x03
tag byte).
Sourcetype UncompressedPointSize: ArraySize
type UncompressedPointSize: ArraySize
Size of an uncompressed point for the given elliptic curve when encoded using the SEC1
Elliptic-Curve-Point-to-Octet-String algorithm (including leading 0x04 tag byte).
Sourcetype UntaggedPointSize: ArraySize + Sub<Self, Output = Self>
type UntaggedPointSize: ArraySize + Sub<Self, Output = Self>
Size of an untagged point for given elliptic curve, i.e. size of two serialized base field elements when concatenated.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.