pub trait ToEncodedPoint<C>: ToSec1Point<C>{ }👎Deprecated since 0.14.0:
use ToSec1Point instead
DEPRECATED: stub trait to help discover the new name for ToSec1Point.
pub trait ToEncodedPoint<C>: ToSec1Point<C>{ }use ToSec1Point instead
DEPRECATED: stub trait to help discover the new name for ToSec1Point.