pub trait ToEncodedPoint<C>: ToSec1Point<C>{ }👎Deprecated since 0.14.0: use
ToSec1Point insteadExpand description
DEPRECATED: stub trait to help discover the new name for ToSec1Point.
pub trait ToEncodedPoint<C>: ToSec1Point<C>{ }ToSec1Point insteadDEPRECATED: stub trait to help discover the new name for ToSec1Point.